import React, { useState, useEffect, useRef } from 'react';
import { motion } from 'framer-motion';
import { Link, useLocation, useNavigate } from 'react-router-dom';
import { Menu, X, Anchor, ChevronDown, Search, Calendar } from 'lucide-react';
import { db } from '../lib/db';
import { useSettingsStore } from '../store/settingsStore';
import { getWhatsAppLink } from '../constants';
import ReservationModal from './ReservationModal';
import type { Category } from '../types';

const Header = () => {
  const [isOpen, setIsOpen] = useState(false);
  const [scrollPosition, setScrollPosition] = useState(0);
  const [isDropdownOpen, setIsDropdownOpen] = useState(false);
  const [isSearchOpen, setIsSearchOpen] = useState(false);
  const [isReservationModalOpen, setIsReservationModalOpen] = useState(false);
  const [categories, setCategories] = useState<Category[]>([]);
  const [isLoading, setIsLoading] = useState(true);
  const location = useLocation();
  const navigate = useNavigate();
  const categoriesCache = useRef<{data: Category[], timestamp: number} | null>(null);

  const { general } = useSettingsStore();
  const { siteName, siteShortName, logoUrl, headerFontFamily } = general;

  useEffect(() => {
    const fetchCategories = async () => {
      try {
        setIsLoading(true);
        
        // Check if we have cached data less than 5 minutes old
        const now = Date.now();
        if (categoriesCache.current && (now - categoriesCache.current.timestamp < 5 * 60 * 1000)) {
          setCategories(categoriesCache.current.data);
          setIsLoading(false);
          return;
        }
        
        let data;
        try {
          data = await db.categories.getAll();
        } catch (error) {
          console.error('Error fetching categories in Header:', error);
          // Use mock data
          data = [
            {
              id: 'cesme-yat-kiralama',
              name: 'Çeşme Yat Kiralama',
              slug: 'cesme-yat-kiralama',
              description: 'Çeşme\'nin berrak sularında özel yat kiralamaları.',
              image_url: 'https://images.pexels.com/photos/163236/pexels-photo-163236.jpeg',
              location: 'Çeşme',
              is_active: true
            },
            {
              id: 'cesme-beach-club-rezervasyonu',
              name: 'Çeşme Beach Club',
              slug: 'cesme-beach-club-rezervasyonu',
              description: 'Çeşme ve Alaçatı\'nın en popüler beach club\'larında rezervasyon.',
              image_url: 'https://images.pexels.com/photos/1289422/pexels-photo-1289422.jpeg',
              location: 'Çeşme/Alaçatı',
              is_active: true
            }
          ];
        }
        
        // Cache the results
        categoriesCache.current = {
          data: data || [],
          timestamp: now
        };
        
        setCategories(data || []);
      } catch (error) {
        console.error('Error fetching categories:', error);
      } finally {
        setIsLoading(false);
      }
    };

    fetchCategories();
  }, []);

  useEffect(() => {
    const handleScroll = () => {
      setScrollPosition(window.scrollY);
    };

    window.addEventListener('scroll', handleScroll);
    return () => {
      window.removeEventListener('scroll', handleScroll);
    };
  }, []);

  const isHomepage = location.pathname === '/';
  const headerClass = scrollPosition > 50 || !isHomepage
    ? 'bg-white shadow-md py-3' 
    : 'bg-transparent py-4';

  const menuLinkStyle = {
    color: scrollPosition > 50 || !isHomepage ? '#1F2937' : '#FFFFFF',
    fontFamily: headerFontFamily,
  };

  const handleSmoothScroll = (e: React.MouseEvent<HTMLAnchorElement>, targetId: string) => {
    e.preventDefault();
    
    if (!isHomepage) {
      navigate('/', { state: { scrollTo: targetId } });
      return;
    }

    const element = document.getElementById(targetId);
    if (element) {
      const headerOffset = 80;
      const elementPosition = element.getBoundingClientRect().top;
      const offsetPosition = elementPosition + window.pageYOffset - headerOffset;

      window.scrollTo({
        top: offsetPosition,
        behavior: 'smooth'
      });
    }
  };

  // Handle scroll after navigation
  useEffect(() => {
    if (isHomepage && location.state?.scrollTo) {
      const targetId = location.state.scrollTo;
      setTimeout(() => {
        const element = document.getElementById(targetId);
        if (element) {
          const headerOffset = 80;
          const elementPosition = element.getBoundingClientRect().top;
          const offsetPosition = elementPosition + window.pageYOffset - headerOffset;

          window.scrollTo({
            top: offsetPosition,
            behavior: 'smooth'
          });
        }
      }, 100);

      // Clear the state after scrolling
      window.history.replaceState({}, document.title);
    }
  }, [isHomepage, location.state]);

  return (
    <>
      <header className={`fixed top-0 left-0 right-0 z-50 transition-all duration-300 ${headerClass}`}>
        <div className="container mx-auto px-4">
          <div className="flex justify-between items-center">
            <Link to="/" className="flex items-center">
              {logoUrl ? (
                <img src={logoUrl} alt={siteName} className="h-8 mr-2" />
              ) : (
                <div className="flex items-center">
                  <span className="font-bold text-xl" style={{...menuLinkStyle, color: scrollPosition > 50 || !isHomepage ? '#1F2937' : '#FFFFFF'}}>
                    Cesme
                  </span>
                  <span className="font-bold text-xl text-yellow-400">
                    Rezervasyon
                  </span>
                  <span className="font-bold text-xl" style={{...menuLinkStyle, color: scrollPosition > 50 || !isHomepage ? '#1F2937' : '#FFFFFF'}}>
                    .com
                  </span>
                </div>
              )}
            </Link>

            {/* Desktop Menu */}
            <nav className="hidden md:flex items-center space-x-8">
              <Link 
                to="/" 
                className="font-bold text-lg transition-all duration-200 border-b-2 border-transparent hover:border-yellow-500"
                style={menuLinkStyle}
              >
                Ana Sayfa
              </Link>
              
              <div 
                className="relative group" 
                onMouseEnter={() => setIsDropdownOpen(true)} 
                onMouseLeave={() => setIsDropdownOpen(false)}
              >
                <button 
                  className="flex items-center font-bold text-lg transition-all duration-200 border-b-2 border-transparent hover:border-yellow-500"
                  style={menuLinkStyle}
                >
                  Rezervasyonlar <ChevronDown className="ml-1 h-4 w-4" />
                </button>
                
                {isDropdownOpen && (
                  <div className="absolute left-0 mt-2 w-64 bg-white rounded-lg shadow-xl py-2 z-50">
                    {isLoading ? (
                      <div className="px-4 py-2">
                        <div className="animate-pulse space-y-2">
                          {[...Array(6)].map((_, i) => (
                            <div key={i} className="h-4 bg-gray-200 rounded"></div>
                          ))}
                        </div>
                      </div>
                    ) : (
                      categories.map((category) => (
                        <Link 
                          key={category.id}
                          to={`/kategori/${category.id}`}
                          className="block px-4 py-2 text-gray-800 hover:bg-yellow-500 hover:text-black transition"
                          onClick={() => setIsDropdownOpen(false)}
                        >
                          {category.name}
                        </Link>
                      ))
                    )}
                  </div>
                )}
              </div>
              
              <a 
                href="/#how-it-works" 
                className="font-bold text-lg transition-all duration-200 border-b-2 border-transparent hover:border-yellow-500"
                style={menuLinkStyle}
                onClick={(e) => handleSmoothScroll(e, 'how-it-works')}
              >
                Nasıl Çalışır
              </a>
              
              <a 
                href="/#testimonials" 
                className="font-bold text-lg transition-all duration-200 border-b-2 border-transparent hover:border-yellow-500"
                style={menuLinkStyle}
                onClick={(e) => handleSmoothScroll(e, 'testimonials')}
              >
                Yorumlar
              </a>
              
              <a 
                href="/#footer" 
                className="font-bold text-lg transition-all duration-200 border-b-2 border-transparent hover:border-yellow-500"
                style={menuLinkStyle}
                onClick={(e) => handleSmoothScroll(e, 'footer')}
              >
                İletişim
              </a>

              <button 
                onClick={() => setIsSearchOpen(!isSearchOpen)} 
                className="p-2 rounded-full hover:bg-yellow-500 hover:bg-opacity-10"
                style={menuLinkStyle}
              >
                <Search className="w-5 h-5" />
              </button>
            </nav>

            {/* Rezervasyon Button */}
            <button 
              onClick={() => setIsReservationModalOpen(true)}
              className="hidden md:flex items-center px-6 py-3 bg-yellow-500 text-black rounded-full hover:bg-yellow-400 transition-colors font-bold shadow-lg"
            >
              <Calendar className="w-4 h-4 mr-2" />
              Rezervasyon
            </button>

            {/* Mobile Menu Button */}
            <button
              className="md:hidden"
              onClick={() => setIsOpen(!isOpen)}
              style={menuLinkStyle}
            >
              {isOpen ? <X className="w-6 h-6" /> : <Menu className="w-6 h-6" />}
            </button>
          </div>
        </div>

        {/* Mobile Menu */}
        {isOpen && (
          <motion.div 
            initial={{ opacity: 0, y: -20 }}
            animate={{ opacity: 1, y: 0 }}
            exit={{ opacity: 0, y: -20 }}
            transition={{ duration: 0.2 }}
            className="md:hidden bg-white shadow-xl"
          >
            <div className="container mx-auto px-4 py-4">
              <nav className="flex flex-col space-y-4">
                <div className="flex items-center gap-2 bg-gray-100 rounded-lg p-2">
                  <Search className="w-5 h-5 text-gray-400" />
                  <input
                    type="text"
                    placeholder="Beach club, restoran, yat turu ara..."
                    className="w-full bg-transparent outline-none"
                  />
                </div>

                <Link 
                  to="/" 
                  className="font-bold text-lg transition py-2 text-gray-800"
                  onClick={() => setIsOpen(false)}
                >
                  Ana Sayfa
                </Link>
                
                {isLoading ? (
                  <div className="py-2 pl-4">
                    <div className="animate-pulse space-y-2">
                      {[...Array(4)].map((_, i) => (
                        <div key={i} className="h-4 bg-gray-200 rounded w-3/4"></div>
                      ))}
                    </div>
                  </div>
                ) : (
                  categories.map((category) => (
                    <Link 
                      key={category.id}
                      to={`/kategori/${category.id}`}
                      className="font-bold text-lg transition py-2 pl-4 text-gray-800"
                      onClick={() => setIsOpen(false)}
                    >
                      {category.name}
                    </Link>
                  ))
                )}
                
                <a 
                  href="/#how-it-works" 
                  className="font-bold text-lg transition py-2 text-gray-800"
                  onClick={(e) => {
                    setIsOpen(false);
                    handleSmoothScroll(e, 'how-it-works');
                  }}
                >
                  Nasıl Çalışır
                </a>
                
                <a 
                  href="/#testimonials" 
                  className="font-bold text-lg transition py-2 text-gray-800"
                  onClick={(e) => {
                    setIsOpen(false);
                    handleSmoothScroll(e, 'testimonials');
                  }}
                >
                  Yorumlar
                </a>
                
                <a 
                  href="/#footer" 
                  className="font-bold text-lg transition py-2 text-gray-800"
                  onClick={(e) => {
                    setIsOpen(false);
                    handleSmoothScroll(e, 'footer');
                  }}
                >
                  İletişim
                </a>
                
                <button 
                  onClick={() => {
                    setIsOpen(false);
                    setIsReservationModalOpen(true);
                  }}
                  className="flex items-center px-4 py-2 bg-yellow-500 text-black rounded-full hover:bg-yellow-400 transition-colors mt-4 font-bold"
                >
                  <Calendar className="w-4 h-4 mr-2" />
                  Rezervasyon
                </button>
              </nav>
            </div>
          </motion.div>
        )}

        {/* Search Modal */}
        {isSearchOpen && (
          <div className="fixed inset-0 bg-black bg-opacity-50 z-50 flex items-start justify-center pt-20">
            <div className="bg-white rounded-lg shadow-xl p-6 w-full max-w-2xl mx-4">
              <div className="flex items-center gap-2 mb-4">
                <Search className="w-5 h-5 text-gray-400" />
                <input
                  type="text"
                  placeholder="Beach club, restoran, yat turu ara..."
                  className="w-full p-2 outline-none text-lg"
                  autoFocus
                />
                <button 
                  onClick={() => setIsSearchOpen(false)}
                  className="text-gray-500 hover:text-gray-700"
                >
                  <X className="w-5 h-5" />
                </button>
              </div>
              <div className="border-t pt-4">
                <h3 className="text-sm font-medium text-gray-500 mb-2">Popüler Aramalar</h3>
                <div className="flex flex-wrap gap-2">
                  {isLoading ? (
                    <div className="animate-pulse flex flex-wrap gap-2">
                      {[...Array(5)].map((_, i) => (
                        <div key={i} className="h-8 bg-gray-200 rounded-full w-24"></div>
                      ))}
                    </div>
                  ) : (
                    categories.slice(0, 5).map((category) => (
                      <Link
                        key={category.id}
                        to={`/kategori/${category.id}`}
                        onClick={() => setIsSearchOpen(false)}
                        className="px-3 py-1 bg-gray-100 rounded-full text-sm text-gray-700 hover:bg-yellow-500 hover:text-black transition"
                      >
                        {category.name}
                      </Link>
                    ))
                  )}
                </div>
              </div>
            </div>
          </div>
        )}
      </header>

      {/* Reservation Modal */}
      <ReservationModal 
        isOpen={isReservationModalOpen}
        onClose={() => setIsReservationModalOpen(false)}
      />
    </>
  );
};

export default Header;